==> gnome-photos-3.15.91.tar.xz: gnome-photos-3.15.91/src/photos-overview-searchbar.h <==
/*
 * Photos - access, organize and share your photos on GNOME
 * Copyright © 2014 Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/* Based on code from:
 *   + Documents
 */

#ifndef PHOTOS_OVERVIEW_SEARCHBAR_H
#define PHOTOS_OVERVIEW_SEARCHBAR_H

#include "photos-dropdown.h"
#include "photos-searchbar.h"

G_BEGIN_DECLS

#define PHOTOS_TYPE_OVERVIEW_SEARCHBAR (photos_overview_searchbar_get_type ())

#define PHOTOS_OVERVIEW_SEARCHBAR(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR, PhotosOverviewSearchbar))

#define PHOTOS_OVERVIEW_SEARCHBAR_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR, PhotosOverviewSearchbarClass))

#define PHOTOS_IS_OVERVIEW_SEARCHBAR(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR))

#define PHOTOS_IS_OVERVIEW_SEARCHBAR_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR))

#define PHOTOS_OVERVIEW_SEARCHBAR_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR, PhotosOverviewSearchbarClass))

typedef struct _PhotosOverviewSearchbar        PhotosOverviewSearchbar;
typedef struct _PhotosOverviewSearchbarClass   PhotosOverviewSearchbarClass;
typedef struct _PhotosOverviewSearchbarPrivate PhotosOverviewSearchbarPrivate;

struct _PhotosOverviewSearchbar
{
  PhotosSearchbar parent_instance;
  PhotosOverviewSearchbarPrivate *priv;
};

struct _PhotosOverviewSearchbarClass
{
  PhotosSearchbarClass parent_class;
};

GType                photos_overview_searchbar_get_type                      (void) G_GNUC_CONST;

GtkWidget           *photos_overview_searchbar_new                           (PhotosDropdown *dropdown);

G_END_DECLS

#endif /* PHOTOS_OVERVIEW_SEARCHBAR_H */

==> gnome-photos_3.18.2.orig.tar.xz: gnome-photos-3.18.2/src/photos-overview-searchbar.h <==
/*
 * Photos - access, organize and share your photos on GNOME
 * Copyright © 2014 Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/* Based on code from:
 *   + Documents
 */

#ifndef PHOTOS_OVERVIEW_SEARCHBAR_H
#define PHOTOS_OVERVIEW_SEARCHBAR_H

#include "photos-dropdown.h"
#include "photos-searchbar.h"

G_BEGIN_DECLS

#define PHOTOS_TYPE_OVERVIEW_SEARCHBAR (photos_overview_searchbar_get_type ())

#define PHOTOS_OVERVIEW_SEARCHBAR(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR, PhotosOverviewSearchbar))

#define PHOTOS_OVERVIEW_SEARCHBAR_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR, PhotosOverviewSearchbarClass))

#define PHOTOS_IS_OVERVIEW_SEARCHBAR(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR))

#define PHOTOS_IS_OVERVIEW_SEARCHBAR_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR))

#define PHOTOS_OVERVIEW_SEARCHBAR_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
   PHOTOS_TYPE_OVERVIEW_SEARCHBAR, PhotosOverviewSearchbarClass))

typedef struct _PhotosOverviewSearchbar        PhotosOverviewSearchbar;
typedef struct _PhotosOverviewSearchbarClass   PhotosOverviewSearchbarClass;
typedef struct _PhotosOverviewSearchbarPrivate PhotosOverviewSearchbarPrivate;

struct _PhotosOverviewSearchbar
{
  PhotosSearchbar parent_instance;
  PhotosOverviewSearchbarPrivate *priv;
};

struct _PhotosOverviewSearchbarClass
{
  PhotosSearchbarClass parent_class;
};

GType                photos_overview_searchbar_get_type                      (void) G_GNUC_CONST;

GtkWidget           *photos_overview_searchbar_new                           (void);

G_END_DECLS

#endif /* PHOTOS_OVERVIEW_SEARCHBAR_H */
